# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from access_server_connector.models.wrapped_response_rule_preset_list_out import WrappedResponseRulePresetListOut  # noqa: E501

class TestWrappedResponseRulePresetListOut(unittest.TestCase):
    """WrappedResponseRulePresetListOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseRulePresetListOut:
        """Test WrappedResponseRulePresetListOut
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseRulePresetListOut`
        """
        model = WrappedResponseRulePresetListOut()  # noqa: E501
        if include_optional:
            return WrappedResponseRulePresetListOut(
                done = True,
                result = access_server_connector.models.rule_preset_list_out.RulePresetListOut(
                    presets = [
                        access_server_connector.models.rule_preset_out.RulePresetOut(
                            id = 56, 
                            name = '', 
                            resource_type = null, 
                            access_mode = 'available', 
                            unlock_delay_ms = 56, 
                            unlock_align_cron = '', 
                            access_duration_ms = 56, 
                            starts_at = 56, 
                            ends_at = 56, 
                            window_cron = '', 
                            window_duration_ms = 56, 
                            timezone = '', 
                            binding = 'single', 
                            expired_message = '', 
                            created_at = 56, 
                            updated_at = 56, )
                        ], 
                    presets_by_type = {
                        'key' : [
                            access_server_connector.models.rule_preset_out.RulePresetOut(
                                id = 56, 
                                name = '', 
                                resource_type = null, 
                                access_mode = 'available', 
                                unlock_delay_ms = 56, 
                                unlock_align_cron = '', 
                                access_duration_ms = 56, 
                                starts_at = 56, 
                                ends_at = 56, 
                                window_cron = '', 
                                window_duration_ms = 56, 
                                timezone = '', 
                                binding = 'single', 
                                expired_message = '', 
                                created_at = 56, 
                                updated_at = 56, )
                            ]
                        }, )
            )
        else:
            return WrappedResponseRulePresetListOut(
                result = access_server_connector.models.rule_preset_list_out.RulePresetListOut(
                    presets = [
                        access_server_connector.models.rule_preset_out.RulePresetOut(
                            id = 56, 
                            name = '', 
                            resource_type = null, 
                            access_mode = 'available', 
                            unlock_delay_ms = 56, 
                            unlock_align_cron = '', 
                            access_duration_ms = 56, 
                            starts_at = 56, 
                            ends_at = 56, 
                            window_cron = '', 
                            window_duration_ms = 56, 
                            timezone = '', 
                            binding = 'single', 
                            expired_message = '', 
                            created_at = 56, 
                            updated_at = 56, )
                        ], 
                    presets_by_type = {
                        'key' : [
                            access_server_connector.models.rule_preset_out.RulePresetOut(
                                id = 56, 
                                name = '', 
                                resource_type = null, 
                                access_mode = 'available', 
                                unlock_delay_ms = 56, 
                                unlock_align_cron = '', 
                                access_duration_ms = 56, 
                                starts_at = 56, 
                                ends_at = 56, 
                                window_cron = '', 
                                window_duration_ms = 56, 
                                timezone = '', 
                                binding = 'single', 
                                expired_message = '', 
                                created_at = 56, 
                                updated_at = 56, )
                            ]
                        }, ),
        )
        """

    def testWrappedResponseRulePresetListOut(self):
        """Test WrappedResponseRulePresetListOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt
from access_server_connector.models.node_access_out import NodeAccessOut

class ResolveOut(BaseModel):
    """
    ResolveOut
    """
    root: NodeAccessOut = Field(...)
    next_transition: Optional[StrictInt] = Field(...)
    __properties = ["root", "next_transition"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResolveOut:
        """Create an instance of ResolveOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of root
        if self.root:
            _dict['root'] = self.root.to_dict()
        # set to None if next_transition (nullable) is None
        # and __fields_set__ contains the field
        if self.next_transition is None and "next_transition" in self.__fields_set__:
            _dict['next_transition'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResolveOut:
        """Create an instance of ResolveOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResolveOut.parse_obj(obj)

        _obj = ResolveOut.parse_obj({
            "root": NodeAccessOut.from_dict(obj.get("root")) if obj.get("root") is not None else None,
            "next_transition": obj.get("next_transition")
        })
        return _obj


